# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the help
button.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class Manager(object):
	"""
	This class defines the behavior of the help button.
	"""

	def __init__(self, player):
		"""
		Initialize object.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__init_attributes(player)
		self.__sig_id_1 = self.__button.connect("clicked", self.__clicked_cb)
		from gobject import timeout_add
		timeout_add(100, self.__determine_sensitivity)

	def __init_attributes(self, player):
		"""
		Initialize data attributes.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__player = player
		self.__button = player.glade.get_widget("HelpButton")
		return

	def __determine_sensitivity(self):
		"""
		Enable the help button only after the help plugin has been
		initialized.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		from operator import contains, not_
		names = self.__player.get_trigger_names()
		if not_(contains(names, "show_user_guide")): return True
		self.__button.set_property("sensitive", True)
		return False

	def __clicked_cb(self, *args):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		self.__player.trigger("show_user_guide")
		return True

	def destroy(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the Manager instance.
		@type self: A Manager object.
		"""
		from Striim.utils import delete_attributes, disconnect_signal
		disconnect_signal(self.__sig_id_1, self.__button)
		self.__button.destroy()
		delete_attributes(self)
		del self
		self = None
		return
